@@ -85,7 +85,7 @@ class ShipmentOut:
                         break
                 else:
                     self.raise_user_error('phone_required', {
-                            'party': self.customer.rec_name,
+                            'party': party.rec_name,
                             })
             if not self.shipping_description:
                 if (any(p.type.ups_code != '01' for p in self.root_packages)
@@ -249,7 +249,7 @@ class CreateShippingUPS(Wizard):
                 'AddressLine': (address.street or '').splitlines(),
                 'City': address.city,
                 'PostalCode': address.zip,
-                'CountryCode': address.country.code,
+                'CountryCode': address.country.code if address.country else '',
                 },
             }
 
